"""Configuration for the OpenCode session adapter."""

from pathlib import Path

from pydantic import BaseModel


class OpenCodeConfig(BaseModel):
    """Configuration for locating the OpenCode SQLite database.

    Attributes:
        db_path: Path to the OpenCode SQLite database file.
    """

    db_path: Path = Path.home() / ".local" / "share" / "opencode" / "opencode.db"
